#!/bin/bash


#if [[ $(which kind) && $(sudo kind --version) ]]; then
#         echo "kind is installed, starting kind"
#     else
#         echo"install kind using install-kind.sh file"
#         echo
#fi




sudo rm -rf /usr/local/bin/kind
echo "kind completely removed"
