#!/bin/sh
wget https://registrationcenter-download.intel.com/akdlm/irc_nas/18486/l_AIKit_p_2022.1.2.135.sh
sudo sh ./l_AIKit_p_2022.1.2.135.sh
sudo sh ./l_AIKit_p_2022.1.2.135.sh -a --silent --eula accept
/opt/intel/oneapi
