#!/bin/bash
sudo pip3 install edgesoftware
echo "Installing smartvr–livestreaming-of-immersive-media ..." 
echo 634e374f-b086-411a-916a-53da4b2739db | $HOME/.local/bin/edgesoftware install smartvr–livestreaming-of-immersive-media 62342da3905e50fbc0da8ac5
~

