#!/bin/bash

#python3 -m pip install --upgrade pip --user && python3 -m pip install edgesoftware --user
pip3 install edgesoftware

echo "Installing wireless-network-ready-intelligent-traffic-management ..."
echo 04b8af94-ecea-4377-bf8c-19592d3ac4f7 | $HOME/.local/bin/edgesoftware install wireless-network-ready-intelligent-traffic-management 623c98999654a8f4bd94f55b




