#!/bin/bash



echo "Installing social-distancing-for-retail-settings ..."
pip3 install edgesoftware
sudo mkdir social-distancing-for-retail-settings 
cd social-distancing-for-retail-settings 
echo 0bc6f800-f667-464d-af07-9ad7fc03606b | $HOME/.local/bin/edgesoftware install social-distancing-for-retail-settings 627a09c506338088f3910d81

