#!/bin/bash

sudo pip3 install edgesoftware
echo "Installing telehealth-remote-monitoring ..." 
echo 8cd89fbf-351e-4d5a-ac5c-c11a33f9d819 | $HOME/.local/bin/edgesoftware install telehealth-remote-monitoring 6221e295905e50fbc05dd07c
~

