#!/bin/bash

sudo pip3 install edgesoftware
echo "Installing intelligent-connection-management-for-automated-handover ..." 
echo c259ebe1-e326-46e3-b2fd-1f95e20476ad | $HOME/.local/bin/edgesoftware install wireless-network-ready-pcb-defect-detection 6221e257905e50fbc05dc793
~

