#!/bin/bash



echo "Installing rotor-bearing-defect-detector ..."
pip3 install edgesoftware
sudo mkdir rotor-bearing-defect-detector
cd rotor-bearing-defect-detector 
echo dfde7618-2fa5-4f31-a776-22f82dc59c10 | $HOME/.local/bin/edgesoftware install wireless-network-ready-intelligent-traffic-management 6170f2ddd8ecccee551a72fa

