#!/bin/bash

sudo pip3 install edgesoftware
echo "Installing intelligent-connection-management-for-automated-handover ..." 
echo 54459efe-476d-4574-b1e2-aadb9482a78a | $HOME/.local/bin/edgesoftware install intelligent-connection-management-for-automated-handover 6241499a9654a8f4bd360ec5
~

