#!/bin/bash



echo "Installing retail-real-time-sensor-fusion-for-loss-detection ..."
pip3 install edgesoftware
sudo mkdir retail-real-time-sensor-fusion-for-loss-detection 
cd retail-real-time-sensor-fusion-for-loss-detection 
echo 8ecf6818-1c42-40bf-a5c5-2d0043575ffb | $HOME/.local/bin/edgesoftware install retail-real-time-sensor-fusion-for-loss-detection 61712992d8ecccee5521c566

